# Changelog

<!--next-version-placeholder-->

## v1.1.0 (2022-05-21)
### Feature
* Init profile service ([`a48c1fe`](https://github.com/draganagrbic998/devops_profile_service3/commit/a48c1fee598127b0b557cbb8bcbe3d08bb0c78d3))
